import { Printer } from '@shared/index';
import { TestPrinter } from './test-printer';
import { SerialPrinter } from './serial-printer';
import logger from '../logger';
import { PrintHistoryRepository, StepRepository } from '../db/repositories';

export function createPrinter(printHistoryRepo: PrintHistoryRepository, stepRepo: StepRepository): Printer {
  if (process.env.NODE_ENV === 'production') {
    logger.info('Using serial printer driver');
    return new SerialPrinter(printHistoryRepo, stepRepo);
  } else {
    logger.info('Using test printer driver');
    return new TestPrinter(printHistoryRepo, stepRepo);
  }
}

export { SerialPrinter } from './serial-printer';
export { TestPrinter } from './test-printer';